django_auxilium.utils.functools package
=======================================

.. automodule:: django_auxilium.utils.functools
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

.. toctree::

   django_auxilium.utils.functools.cache
   django_auxilium.utils.functools.decorators
   django_auxilium.utils.functools.lazy

